@@ -24,8 +24,8 @@ pref("browser.search.param.yahoo-fr", "linuxmint");
 
 // Set the UserAgent
 pref("general.useragent.vendor", "Linux Mint");
-pref("general.useragent.vendorSub", "18");
-pref("general.useragent.vendorComment", "Sarah");
+pref("general.useragent.vendorSub", "18.1");
+pref("general.useragent.vendorComment", "Serena");
 
 // Default search engine
 pref("browser.search.searchEnginesURL", "http://www.linuxmint.com/searchengines/");
